# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from stadiamaps.models.road_class import RoadClass

class RoutingWaypointAllOfSearchFilter(BaseModel):
    """
    RoutingWaypointAllOfSearchFilter
    """
    exclude_tunnel: Optional[StrictBool] = Field(False, description="Excludes roads marked as tunnels")
    exclude_bridge: Optional[StrictBool] = Field(False, description="Excludes roads marked as bridges")
    exclude_ramp: Optional[StrictBool] = Field(False, description="Excludes roads marked as ramps")
    exclude_closures: Optional[StrictBool] = Field(True, description="Excludes roads marked as closed")
    min_road_class: Optional[RoadClass] = None
    max_road_class: Optional[RoadClass] = None
    additional_properties: Dict[str, Any] = {}
    __properties = ["exclude_tunnel", "exclude_bridge", "exclude_ramp", "exclude_closures", "min_road_class", "max_road_class"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RoutingWaypointAllOfSearchFilter:
        """Create an instance of RoutingWaypointAllOfSearchFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RoutingWaypointAllOfSearchFilter:
        """Create an instance of RoutingWaypointAllOfSearchFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RoutingWaypointAllOfSearchFilter.parse_obj(obj)

        _obj = RoutingWaypointAllOfSearchFilter.parse_obj({
            "exclude_tunnel": obj.get("exclude_tunnel") if obj.get("exclude_tunnel") is not None else False,
            "exclude_bridge": obj.get("exclude_bridge") if obj.get("exclude_bridge") is not None else False,
            "exclude_ramp": obj.get("exclude_ramp") if obj.get("exclude_ramp") is not None else False,
            "exclude_closures": obj.get("exclude_closures") if obj.get("exclude_closures") is not None else True,
            "min_road_class": obj.get("min_road_class"),
            "max_road_class": obj.get("max_road_class")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, validator
from stadiamaps.models.access import Access
from stadiamaps.models.administrative import Administrative
from stadiamaps.models.node_id import NodeId
from stadiamaps.models.node_type import NodeType

class LocateNode(BaseModel):
    """
    LocateNode
    """
    lat: Union[StrictFloat, StrictInt] = Field(..., description="The latitude of a point in the shape.")
    lon: Union[StrictFloat, StrictInt] = Field(..., description="The longitude of a point in the shape.")
    traffic_signal: Optional[StrictBool] = None
    type: Optional[NodeType] = None
    node_id: Optional[NodeId] = None
    access: Optional[Access] = None
    edge_count: Optional[StrictInt] = None
    administrative: Optional[Administrative] = None
    intersection_type: Optional[StrictStr] = None
    density: Optional[StrictInt] = None
    local_edge_count: Optional[StrictInt] = None
    mode_change: Optional[StrictBool] = None
    additional_properties: Dict[str, Any] = {}
    __properties = ["lat", "lon", "traffic_signal", "type", "node_id", "access", "edge_count", "administrative", "intersection_type", "density", "local_edge_count", "mode_change"]

    @validator('intersection_type')
    def intersection_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('regular', 'false', 'dead-end', 'fork'):
            raise ValueError("must be one of enum values ('regular', 'false', 'dead-end', 'fork')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LocateNode:
        """Create an instance of LocateNode from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of node_id
        if self.node_id:
            _dict['node_id'] = self.node_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of access
        if self.access:
            _dict['access'] = self.access.to_dict()
        # override the default output from pydantic by calling `to_dict()` of administrative
        if self.administrative:
            _dict['administrative'] = self.administrative.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LocateNode:
        """Create an instance of LocateNode from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LocateNode.parse_obj(obj)

        _obj = LocateNode.parse_obj({
            "lat": obj.get("lat"),
            "lon": obj.get("lon"),
            "traffic_signal": obj.get("traffic_signal"),
            "type": obj.get("type"),
            "node_id": NodeId.from_dict(obj.get("node_id")) if obj.get("node_id") is not None else None,
            "access": Access.from_dict(obj.get("access")) if obj.get("access") is not None else None,
            "edge_count": obj.get("edge_count"),
            "administrative": Administrative.from_dict(obj.get("administrative")) if obj.get("administrative") is not None else None,
            "intersection_type": obj.get("intersection_type"),
            "density": obj.get("density"),
            "local_edge_count": obj.get("local_edge_count"),
            "mode_change": obj.get("mode_change")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.geocoding_api import GeocodingApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestGeocodingApi(unittest.TestCase):
    """GeocodingApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.geocoding_api.GeocodingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_autocomplete(self):
        """Test case for autocomplete

        Search and geocode quickly based on partial input.  # noqa: E501
        """
        pass

    def test_place(self):
        """Test case for place

        Retrieve details of a place using its GID.  # noqa: E501
        """
        pass

    def test_reverse(self):
        """Test case for reverse

        Find places and addresses near geographic coordinates (reverse geocoding).  # noqa: E501
        """
        pass

    def test_search(self):
        """Test case for search

        Search for location and other info using a place name or address (forward geocoding).  # noqa: E501
        """
        pass

    def test_search_structured(self):
        """Test case for search_structured

        Find locations matching components (structured forward geocoding).  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator
from stadiamaps.models.geo_attributes import GeoAttributes
from stadiamaps.models.highway_classification import HighwayClassification
from stadiamaps.models.node_id import NodeId
from stadiamaps.models.restrictions import Restrictions
from stadiamaps.models.speeds import Speeds

class LocateDetailedEdge(BaseModel):
    """
    LocateDetailedEdge
    """
    sidewalk_left: Optional[StrictBool] = Field(None, description="Is there a sidewalk to the left of the edge?")
    sidewalk_right: Optional[StrictBool] = Field(None, description="Is there a sidewalk to the right of the edge?")
    lane_count: Optional[StrictInt] = None
    stop_sign: Optional[StrictBool] = Field(None, description="Is there a stop sign at end of the directed edge?")
    sac_scale: Optional[StrictStr] = None
    yield_sign: Optional[StrictBool] = Field(None, description="Is there a yield sign at end of the directed edge?")
    not_thru: Optional[StrictBool] = Field(None, description="Does the edge lead to a \"no-through\" region?")
    forward: Optional[StrictBool] = Field(None, description="Is the edge info forward? If false, then reverse is implied.")
    end_node: Optional[NodeId] = None
    truck_route: Optional[StrictBool] = Field(None, description="Is the edge part of a truck route/network?")
    speeds: Optional[Speeds] = None
    bike_network: Optional[StrictBool] = Field(None, description="Is the edge part of a bicycle network?")
    round_about: Optional[StrictBool] = Field(None, description="Is the edge part of a roundabout?")
    traffic_signal: Optional[StrictBool] = Field(None, description="Is there a traffic signal at the end of the directed edge?")
    access_restriction: Optional[StrictBool] = Field(None, description="Is there a general restriction or access condition?")
    destination_only: Optional[StrictBool] = Field(None, description="Is the edge destination only? If so, it will not be routed through.")
    geo_attributes: Optional[GeoAttributes] = None
    start_restriction: Optional[Restrictions] = None
    cycle_lane: Optional[StrictStr] = Field(None, description="Indication of the type of cycle lane (if any) present along an edge.")
    end_restriction: Optional[Restrictions] = None
    seasonal: Optional[StrictBool] = Field(None, description="Is access seasonal (ex. no access in winter)?")
    country_crossing: Optional[StrictBool] = Field(None, description="Does the edge cross into a new country?")
    part_of_complex_restriction: Optional[StrictBool] = Field(None, description="Is the edge part of a complex restriction?")
    has_sign: Optional[StrictBool] = Field(None, description="Do exit signs exist for the edge?")
    access: Optional[Restrictions] = None
    bridge: Optional[StrictBool] = Field(None, description="Is the edge part of a bridge?")
    classification: Optional[HighwayClassification] = None
    toll: Optional[StrictBool] = Field(None, description="Is the edge part of a toll road?")
    tunnel: Optional[StrictBool] = Field(None, description="Is the edge part of a tunnel?")
    additional_properties: Dict[str, Any] = {}
    __properties = ["sidewalk_left", "sidewalk_right", "lane_count", "stop_sign", "sac_scale", "yield_sign", "not_thru", "forward", "end_node", "truck_route", "speeds", "bike_network", "round_about", "traffic_signal", "access_restriction", "destination_only", "geo_attributes", "start_restriction", "cycle_lane", "end_restriction", "seasonal", "country_crossing", "part_of_complex_restriction", "has_sign", "access", "bridge", "classification", "toll", "tunnel"]

    @validator('sac_scale')
    def sac_scale_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('none', 'hiking', 'mountain hiking', 'demanding mountain hiking', 'alpine hiking', 'demanding alpine hiking', 'difficult alpine hiking'):
            raise ValueError("must be one of enum values ('none', 'hiking', 'mountain hiking', 'demanding mountain hiking', 'alpine hiking', 'demanding alpine hiking', 'difficult alpine hiking')")
        return value

    @validator('cycle_lane')
    def cycle_lane_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('none', 'shared', 'dedicated', 'separated'):
            raise ValueError("must be one of enum values ('none', 'shared', 'dedicated', 'separated')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LocateDetailedEdge:
        """Create an instance of LocateDetailedEdge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of end_node
        if self.end_node:
            _dict['end_node'] = self.end_node.to_dict()
        # override the default output from pydantic by calling `to_dict()` of speeds
        if self.speeds:
            _dict['speeds'] = self.speeds.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geo_attributes
        if self.geo_attributes:
            _dict['geo_attributes'] = self.geo_attributes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of start_restriction
        if self.start_restriction:
            _dict['start_restriction'] = self.start_restriction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of end_restriction
        if self.end_restriction:
            _dict['end_restriction'] = self.end_restriction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of access
        if self.access:
            _dict['access'] = self.access.to_dict()
        # override the default output from pydantic by calling `to_dict()` of classification
        if self.classification:
            _dict['classification'] = self.classification.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LocateDetailedEdge:
        """Create an instance of LocateDetailedEdge from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LocateDetailedEdge.parse_obj(obj)

        _obj = LocateDetailedEdge.parse_obj({
            "sidewalk_left": obj.get("sidewalk_left"),
            "sidewalk_right": obj.get("sidewalk_right"),
            "lane_count": obj.get("lane_count"),
            "stop_sign": obj.get("stop_sign"),
            "sac_scale": obj.get("sac_scale"),
            "yield_sign": obj.get("yield_sign"),
            "not_thru": obj.get("not_thru"),
            "forward": obj.get("forward"),
            "end_node": NodeId.from_dict(obj.get("end_node")) if obj.get("end_node") is not None else None,
            "truck_route": obj.get("truck_route"),
            "speeds": Speeds.from_dict(obj.get("speeds")) if obj.get("speeds") is not None else None,
            "bike_network": obj.get("bike_network"),
            "round_about": obj.get("round_about"),
            "traffic_signal": obj.get("traffic_signal"),
            "access_restriction": obj.get("access_restriction"),
            "destination_only": obj.get("destination_only"),
            "geo_attributes": GeoAttributes.from_dict(obj.get("geo_attributes")) if obj.get("geo_attributes") is not None else None,
            "start_restriction": Restrictions.from_dict(obj.get("start_restriction")) if obj.get("start_restriction") is not None else None,
            "cycle_lane": obj.get("cycle_lane"),
            "end_restriction": Restrictions.from_dict(obj.get("end_restriction")) if obj.get("end_restriction") is not None else None,
            "seasonal": obj.get("seasonal"),
            "country_crossing": obj.get("country_crossing"),
            "part_of_complex_restriction": obj.get("part_of_complex_restriction"),
            "has_sign": obj.get("has_sign"),
            "access": Restrictions.from_dict(obj.get("access")) if obj.get("access") is not None else None,
            "bridge": obj.get("bridge"),
            "classification": HighwayClassification.from_dict(obj.get("classification")) if obj.get("classification") is not None else None,
            "toll": obj.get("toll"),
            "tunnel": obj.get("tunnel")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.locate_object import LocateObject  # noqa: E501
from stadiamaps.rest import ApiException

class TestLocateObject(unittest.TestCase):
    """LocateObject unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LocateObject
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LocateObject`
        """
        model = stadiamaps.models.locate_object.LocateObject()  # noqa: E501
        if include_optional :
            return LocateObject(
                id = 'kesklinn', 
                input_lat = 1.337, 
                input_lon = 1.337, 
                nodes = [
                    null
                    ], 
                edges = [
                    stadiamaps.models.locate_edge.locateEdge(
                        edge_id = stadiamaps.models.node_id.nodeId(
                            id = 56, 
                            value = 56, 
                            tile_id = 56, 
                            level = 56, ), 
                        correlated_lat = 1.337, 
                        correlated_lon = 1.337, 
                        percent_along = 1.337, 
                        side_of_street = 'left', 
                        linear_reference = '', 
                        outbound_reach = 56, 
                        heading = 1.337, 
                        inbound_reach = 56, 
                        distance = 1.337, 
                        predicted_speeds = [
                            56
                            ], 
                        edge_info = stadiamaps.models.locate_edge_info.locateEdgeInfo(
                            mean_elevation = 1.337, 
                            shape = '', 
                            names = [
                                ''
                                ], 
                            bike_network = stadiamaps.models.bike_network.bikeNetwork(
                                mountain = True, 
                                local = True, 
                                regional = True, 
                                national = True, ), 
                            way_id = 56, ), 
                        edge = stadiamaps.models.locate_detailed_edge.locateDetailedEdge(
                            sidewalk_left = True, 
                            sidewalk_right = True, 
                            lane_count = 56, 
                            stop_sign = True, 
                            sac_scale = 'none', 
                            yield_sign = True, 
                            not_thru = True, 
                            forward = True, 
                            end_node = stadiamaps.models.node_id.nodeId(
                                id = 56, 
                                value = 56, 
                                tile_id = 56, 
                                level = 56, ), 
                            truck_route = True, 
                            speeds = stadiamaps.models.speeds.speeds(
                                predicted = True, 
                                constrained_flow = 56, 
                                free_flow = 56, 
                                type = 'classified', 
                                default = 56, ), 
                            round_about = True, 
                            traffic_signal = True, 
                            access_restriction = True, 
                            destination_only = True, 
                            geo_attributes = stadiamaps.models.geo_attributes.geoAttributes(
                                curvature = 56, 
                                max_down_slope = 1.337, 
                                max_up_slope = 1.337, 
                                weighted_grade = 1.337, 
                                length = 56, ), 
                            start_restriction = stadiamaps.models.restrictions.restrictions(
                                golf_cart = True, 
                                truck = True, 
                                pedestrian = True, 
                                wheelchair = True, 
                                taxi = True, 
                                hov = True, 
                                emergency = True, 
                                motorcycle = True, 
                                car = True, 
                                moped = True, 
                                bus = True, 
                                bicycle = True, ), 
                            cycle_lane = 'none', 
                            end_restriction = stadiamaps.models.restrictions.restrictions(
                                golf_cart = True, 
                                truck = True, 
                                pedestrian = True, 
                                wheelchair = True, 
                                taxi = True, 
                                hov = True, 
                                emergency = True, 
                                motorcycle = True, 
                                car = True, 
                                moped = True, 
                                bus = True, 
                                bicycle = True, ), 
                            seasonal = True, 
                            country_crossing = True, 
                            part_of_complex_restriction = True, 
                            has_sign = True, 
                            access = , 
                            bridge = True, 
                            classification = stadiamaps.models.highway_classification.highwayClassification(
                                internal = True, 
                                link = True, 
                                surface = 'paved_smooth', 
                                use = 'road', ), 
                            toll = True, 
                            tunnel = True, ), 
                        warnings = [
                            ''
                            ], )
                    ]
            )
        else :
            return LocateObject(
        )
        """

    def testLocateObject(self):
        """Test LocateObject"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import os
import unittest

import stadiamaps


class TestGeospatial(unittest.TestCase):
    def setUp(self):
        self.configuration = stadiamaps.Configuration()
        self.configuration.api_key["ApiKeyAuth"] = os.environ["STADIA_API_KEY"]

    def tearDown(self):
        pass

    def testTZLookup(self):
        with stadiamaps.ApiClient(self.configuration) as api_client:
            api_instance = stadiamaps.GeospatialApi(api_client)

            res = api_instance.tz_lookup(37.56, 126.99)
            self.assertEqual("Asia/Seoul", res.tz_id)

    def testElevation(self):
        with stadiamaps.ApiClient(self.configuration) as api_client:
            api_instance = stadiamaps.GeospatialApi(api_client)

            req = stadiamaps.HeightRequest(id="Seoul", shape=[stadiamaps.Coordinate(lat=37.56, lon=126.99)])
            res = api_instance.elevation(req)
            self.assertEqual(req.id, res.id)
            self.assertGreaterEqual(len(res.height), 1)
            self.assertGreaterEqual(res.height[0], 1)
            self.assertEqual(res.shape, req.shape)



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.map_match_route_response import MapMatchRouteResponse  # noqa: E501
from stadiamaps.rest import ApiException

class TestMapMatchRouteResponse(unittest.TestCase):
    """MapMatchRouteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MapMatchRouteResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MapMatchRouteResponse`
        """
        model = stadiamaps.models.map_match_route_response.MapMatchRouteResponse()  # noqa: E501
        if include_optional :
            return MapMatchRouteResponse(
                id = 'kesklinn', 
                trip = stadiamaps.models.route_response_trip.routeResponse_trip(
                    status = 56, 
                    status_message = '', 
                    units = 'kilometers', 
                    language = 'en-US', 
                    locations = [
                        null
                        ], 
                    legs = [
                        stadiamaps.models.route_leg.routeLeg(
                            maneuvers = [
                                stadiamaps.models.route_maneuver.routeManeuver(
                                    type = 56, 
                                    instruction = '', 
                                    verbal_transition_alert_instruction = '', 
                                    verbal_pre_transition_instruction = '', 
                                    verbal_post_transition_instruction = '', 
                                    street_names = [
                                        'A1'
                                        ], 
                                    begin_street_names = [
                                        'A1'
                                        ], 
                                    time = 1.337, 
                                    length = 1.337, 
                                    begin_shape_index = 56, 
                                    end_shape_index = 56, 
                                    toll = True, 
                                    rough = True, 
                                    gate = True, 
                                    ferry = True, 
                                    sign = stadiamaps.models.maneuver_sign.maneuverSign(
                                        exit_number_elements = [
                                            stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                                text = '', 
                                                is_route_number = True, 
                                                consecutive_count = 56, )
                                            ], 
                                        exit_branch_elements = [
                                            stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                                text = '', 
                                                is_route_number = True, 
                                                consecutive_count = 56, )
                                            ], 
                                        exit_toward_elements = [
                                            
                                            ], 
                                        exit_name_elements = [
                                            
                                            ], ), 
                                    roundabout_exit_count = 56, 
                                    depart_instruction = 56, 
                                    verbal_depart_instruction = 56, 
                                    arrive_instruction = 56, 
                                    verbal_arrive_instruction = 56, 
                                    transit_info = { }, 
                                    verbal_multi_cue = True, 
                                    travel_mode = 'drive', 
                                    travel_type = 'car', 
                                    bss_maneuver_type = 'NoneAction', )
                                ], 
                            shape = '', 
                            summary = stadiamaps.models.route_summary.routeSummary(
                                time = 1.337, 
                                length = 1.337, 
                                min_lat = 1.337, 
                                max_lat = 1.337, 
                                min_lon = 1.337, 
                                max_lon = 1.337, ), )
                        ], 
                    summary = stadiamaps.models.route_summary.routeSummary(
                        time = 1.337, 
                        length = 1.337, 
                        min_lat = 1.337, 
                        max_lat = 1.337, 
                        min_lon = 1.337, 
                        max_lon = 1.337, ), ), 
                linear_references = [
                    ''
                    ]
            )
        else :
            return MapMatchRouteResponse(
                trip = stadiamaps.models.route_response_trip.routeResponse_trip(
                    status = 56, 
                    status_message = '', 
                    units = 'kilometers', 
                    language = 'en-US', 
                    locations = [
                        null
                        ], 
                    legs = [
                        stadiamaps.models.route_leg.routeLeg(
                            maneuvers = [
                                stadiamaps.models.route_maneuver.routeManeuver(
                                    type = 56, 
                                    instruction = '', 
                                    verbal_transition_alert_instruction = '', 
                                    verbal_pre_transition_instruction = '', 
                                    verbal_post_transition_instruction = '', 
                                    street_names = [
                                        'A1'
                                        ], 
                                    begin_street_names = [
                                        'A1'
                                        ], 
                                    time = 1.337, 
                                    length = 1.337, 
                                    begin_shape_index = 56, 
                                    end_shape_index = 56, 
                                    toll = True, 
                                    rough = True, 
                                    gate = True, 
                                    ferry = True, 
                                    sign = stadiamaps.models.maneuver_sign.maneuverSign(
                                        exit_number_elements = [
                                            stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                                text = '', 
                                                is_route_number = True, 
                                                consecutive_count = 56, )
                                            ], 
                                        exit_branch_elements = [
                                            stadiamaps.models.maneuver_sign_element.maneuverSignElement(
                                                text = '', 
                                                is_route_number = True, 
                                                consecutive_count = 56, )
                                            ], 
                                        exit_toward_elements = [
                                            
                                            ], 
                                        exit_name_elements = [
                                            
                                            ], ), 
                                    roundabout_exit_count = 56, 
                                    depart_instruction = 56, 
                                    verbal_depart_instruction = 56, 
                                    arrive_instruction = 56, 
                                    verbal_arrive_instruction = 56, 
                                    transit_info = { }, 
                                    verbal_multi_cue = True, 
                                    travel_mode = 'drive', 
                                    travel_type = 'car', 
                                    bss_maneuver_type = 'NoneAction', )
                                ], 
                            shape = '', 
                            summary = stadiamaps.models.route_summary.routeSummary(
                                time = 1.337, 
                                length = 1.337, 
                                min_lat = 1.337, 
                                max_lat = 1.337, 
                                min_lon = 1.337, 
                                max_lon = 1.337, ), )
                        ], 
                    summary = stadiamaps.models.route_summary.routeSummary(
                        time = 1.337, 
                        length = 1.337, 
                        min_lat = 1.337, 
                        max_lat = 1.337, 
                        min_lon = 1.337, 
                        max_lon = 1.337, ), ),
        )
        """

    def testMapMatchRouteResponse(self):
        """Test MapMatchRouteResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.valhalla_long_units import ValhallaLongUnits  # noqa: E501
from stadiamaps.rest import ApiException

class TestValhallaLongUnits(unittest.TestCase):
    """ValhallaLongUnits unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testValhallaLongUnits(self):
        """Test ValhallaLongUnits"""
        # inst = ValhallaLongUnits()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.costing_options import CostingOptions  # noqa: E501
from stadiamaps.rest import ApiException

class TestCostingOptions(unittest.TestCase):
    """CostingOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CostingOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CostingOptions`
        """
        model = stadiamaps.models.costing_options.CostingOptions()  # noqa: E501
        if include_optional :
            return CostingOptions(
                auto = None, 
                bus = None, 
                taxi = None, 
                truck = None, 
                bicycle = None, 
                motor_scooter = None, 
                motorcycle = None, 
                pedestrian = stadiamaps.models.pedestrian_costing_options.pedestrianCostingOptions(
                    walking_speed = 0.5, 
                    walkway_factor = 1.337, 
                    sidewalk_factor = 1.337, 
                    alley_factor = 1.337, 
                    driveway_factor = 1.337, 
                    step_penalty = 56, 
                    use_ferry = 0, 
                    use_living_streets = 0, 
                    use_tracks = 0, 
                    use_hills = 0, 
                    use_lit = 0, 
                    service_penalty = 56, 
                    service_factor = 1.337, 
                    max_hiking_difficulty = 1, 
                    bss_rent_cost = 56, 
                    bss_rent_penalty = 56, )
            )
        else :
            return CostingOptions(
        )
        """

    def testCostingOptions(self):
        """Test CostingOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
